-----------------------------------------------------------------------------------------------
-- Client Lua Script for ReloadUI
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Window"
 
-----------------------------------------------------------------------------------------------
-- ReloadUI Module Definition
-----------------------------------------------------------------------------------------------
local ReloadUI = {} 
 
-----------------------------------------------------------------------------------------------
-- Constants
-----------------------------------------------------------------------------------------------
-- e.g. local kiExampleVariableMax = 999
 
-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function ReloadUI:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    -- initialize variables here
	nb_erreurs = 0
	strTooltip = ""
	strName2 = "erreur"
    return o
end

function ReloadUI:Init()
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {
		-- "UnitOrPackageName",
	}
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
		-- tente de créer un bouton dans l'ui
	Apollo.RegisterEventHandler("InterfaceMenuListHasLoaded", "OnInterfaceMenuListHasLoaded", self)
	Apollo.RegisterEventHandler("ReloadUI", "OnRlBOn", self)
end
 

-----------------------------------------------------------------------------------------------
-- ReloadUI OnLoad
-----------------------------------------------------------------------------------------------
function ReloadUI:OnLoad()
    -- load our form file
	self.xmlDoc = XmlDoc.CreateFromFile("ReloadUI.xml")
	self.xmlDoc:RegisterCallback("OnDocLoaded", self)
end


-----------------------------------------------------------------------------------------------
-- ReloadUI OnDocLoaded
-----------------------------------------------------------------------------------------------
function ReloadUI:OnDocLoaded()

	if self.xmlDoc ~= nil and self.xmlDoc:IsLoaded() then
	    self.wndMain = Apollo.LoadForm(self.xmlDoc, "ReloadUIForm", nil, self)
		if self.wndMain == nil then
			Apollo.AddAddonErrorText(self, "Could not load the main window for some reason.")
			return
		end
		
	    self.wndMain:Show(false, true)

		-- if the xmlDoc is no longer needed, you should set it to nil
		-- self.xmlDoc = nil
		
		-- Register handlers for events, slash commands and timer, etc.
		-- e.g. Apollo.RegisterEventHandler("KeyDown", "OnKeyDown", self)
		Apollo.RegisterSlashCommand("rl","OnRlOn", self)

		-- Do additional Addon initialization here
		-- Appel de la fonction quand on clique sur le bouton
		Apollo.RegisterEventHandler("Reloadui_button", "OnRlOn", self)
	end
	-- Charger les Sprites	
	Apollo.LoadSprites("ReloaduiSprites.xml", "ReloadUIS")
end

-----------------------------------------------------------------------------------------------
-- ReloadUI Functions
-----------------------------------------------------------------------------------------------
-- Define general functions here

-- Action du bouton
function ReloadUI:OnRlOn()
RequestReloadUI()
end

-- On affiche le bouton
function ReloadUI:OnInterfaceMenuListHasLoaded()
	Event_FireGenericEvent("InterfaceMenuList_NewAddOn", "Reload UI", {"Reloadui_button", "", "ReloadUIS:reload36"}) 
	-- Mise à jour du nombre d'erreurs
end

-- On obtient la dernière erreur
function ReloadUI:GetAsyncLoadStatus()
	local ErrorDialogLUA = Apollo.GetAddon("ErrorDialog")
	if not ErrorDialogLUA then
	return Apollo.AddonLoadStatus.Loading
	end
	if not ErrorDialogLUA.wndReportBug then
	return Apollo.AddonLoadStatus.Loading
	end
	-- On supprime la fenetre d'erreur
	Apollo.RemoveEventHandler("LuaError",ErrorDialogLUA)
	Apollo.RegisterEventHandler("LuaError","OnLuaError",self)
	return Apollo.AddonLoadStatus.Loaded
end

-- On calcule combien il y a d'erreurs
function ReloadUI:OnLuaError(tAddon, strError, bCanIgnore)
local tError = {}
tError.tAddon = tAddon
tError.strError = strError
tError.bCanIgnore = bCanIgnore
tError.tLocalTime = GameLib.GetLocalTime()
nb_erreurs = nb_erreurs + 1
-- On affiche dans le chat l'addon qui est en erreur
if tAddon.strName ~= strName2 then
	Print(String_GetWeaselString(Apollo.GetString("LuaError_DebugOutput"), tAddon.strName))
	strName2 = tAddon.strName
end
-- On affiche la derniere erreur
strTooltip = "Last error : " .. tAddon.strName
-- On Affiche le nombre d'erreurs sur l'icone
Event_FireGenericEvent("InterfaceMenuList_AlertAddOn", "Reload UI", {nb_erreurs > 2, strTooltip, nb_erreurs})
end



-----------------------------------------------------------------------------------------------
-- ReloadUI Instance
-----------------------------------------------------------------------------------------------
local ReloadUIInst = ReloadUI:new()
ReloadUIInst:Init()
